"""
Workspace management for nirs4all.

Provides library management for saving and loading pipeline templates and trained models.
"""

from .library_manager import LibraryManager

__all__ = [
    "LibraryManager",
]
