"""Scikit-learn model operators.

This module provides wrappers and utilities for using scikit-learn models
as operators in nirs4all pipelines.
"""

# Sklearn models are typically used directly from sklearn
# This module serves as a placeholder for any sklearn-specific wrappers

__all__ = []
